==> kdenetwork-4.2.0.tar.bz2: kdenetwork-4.2.0/kget/transfer-plugins/bittorrent/libbtcore/interfaces/webseedinterface.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
 *   joris.guisson@gmail.com                                               *
 *   ivasic@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#include "webseedinterface.h"

namespace bt
{

	WebSeedInterface::WebSeedInterface(const KUrl & url,bool user) : url(url),total_downloaded(0),user(user)
	{
	}


	WebSeedInterface::~WebSeedInterface()
	{
	}


}

==> kdenetwork-4.4.2.tar.bz2: kdenetwork-4.4.2/kget/transfer-plugins/bittorrent/libbtcore/interfaces/webseedinterface.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
 *   joris.guisson@gmail.com                                               *
 *   ivasic@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#include "webseedinterface.h"

namespace bt
{

	WebSeedInterface::WebSeedInterface(const KUrl & url,bool user) : url(url),total_downloaded(0),user(user),enabled(true)
	{
	}


	WebSeedInterface::~WebSeedInterface()
	{
	}

	void WebSeedInterface::setEnabled(bool on)
	{
		enabled = on;
	}

}
